@@ -1,7 +1,7 @@
 """
 Type annotations for docdb service literal definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_docdb/literals/)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_docdb/literals.html)
 
 Usage::
 
@@ -37,12 +37,9 @@ __all__ = (
     "DescribeOrderableDBInstanceOptionsPaginatorName",
     "DescribePendingMaintenanceActionsPaginatorName",
     "SourceTypeType",
-    "DocDBServiceName",
     "ServiceName",
-    "ResourceServiceName",
     "PaginatorName",
     "WaiterName",
-    "RegionName",
 )
 
 
@@ -70,7 +67,6 @@ SourceTypeType = Literal[
     "db-security-group",
     "db-snapshot",
 ]
-DocDBServiceName = Literal["docdb"]
 ServiceName = Literal[
     "accessanalyzer",
     "account",
@@ -359,18 +355,6 @@ ServiceName = Literal[
     "workspaces",
     "xray",
 ]
-ResourceServiceName = Literal[
-    "cloudformation",
-    "cloudwatch",
-    "dynamodb",
-    "ec2",
-    "glacier",
-    "iam",
-    "opsworks",
-    "s3",
-    "sns",
-    "sqs",
-]
 PaginatorName = Literal[
     "describe_certificates",
     "describe_db_cluster_parameter_groups",
@@ -387,26 +371,3 @@ PaginatorName = Literal[
     "describe_pending_maintenance_actions",
 ]
 WaiterName = Literal["db_instance_available", "db_instance_deleted"]
-RegionName = Literal[
-    "af-south-1",
-    "ap-east-1",
-    "ap-northeast-1",
-    "ap-northeast-2",
-    "ap-northeast-3",
-    "ap-south-1",
-    "ap-southeast-1",
-    "ap-southeast-2",
-    "ca-central-1",
-    "eu-central-1",
-    "eu-north-1",
-    "eu-south-1",
-    "eu-west-1",
-    "eu-west-2",
-    "eu-west-3",
-    "me-south-1",
-    "sa-east-1",
-    "us-east-1",
-    "us-east-2",
-    "us-west-1",
-    "us-west-2",
-]
